@@ -1,7 +1,7 @@
 from typing import Any, Optional, Union
 
 from lxml import etree
-from pydantic import BaseModel
+from pydantic import BaseModel, ConfigDict
 
 from spei.errors.sice import CodigoErrorAcuseBanxico, CodigoErrorAcuseServidor
 from spei.types.sice import CodigoRespuestaAcuse, TipoRespuestaAcuse
@@ -11,22 +11,18 @@ from spei.utils import to_snake_case  # noqa: WPS347
 class ResultadoBanxico(BaseModel):
     codigo: Optional[CodigoErrorAcuseBanxico] = None
     descripcion: str = 'ND'
-
-    class Config:  # noqa: WPS306, WPS431
-        use_enum_values = True
+    model_config = ConfigDict(use_enum_values=True)
 
 
 class ResultadoServidor(BaseModel):
     codigo: Union[CodigoErrorAcuseServidor, CodigoRespuestaAcuse]
     descripcion: str = 'ND'
-
-    class Config:  # noqa: WPS306, WPS431
-        use_enum_values = True
+    model_config = ConfigDict(use_enum_values=True)
 
 
 class MensajeRespuesta(BaseModel):
     tipo_respuesta: TipoRespuestaAcuse
-    respuesta: Any
+    respuesta: Any = None
 
     @classmethod
     def parse_xml(cls, mensaje):
@@ -57,14 +53,12 @@ class MensajeRespuesta(BaseModel):
 
 
 class Acuse(BaseModel):
-    cda_id: str
+    cda_id: int
     mensaje_id: Any = None
     tipo_respuesta: TipoRespuestaAcuse
     resultado_enlace_cep: ResultadoServidor
     resultado_banxico: Optional[ResultadoBanxico] = None
-
-    class Config:  # noqa: WPS306, WPS431
-        use_enum_values = True
+    model_config = ConfigDict(use_enum_values=True)
 
     @classmethod
     def parse_synchronous_xml(cls, mensaje_element):
@@ -90,13 +84,13 @@ class Acuse(BaseModel):
         if self.mensaje_id:
             acuse = etree.Element(
                 'acuse',
-                idCda=self.cda_id,
-                idMensaje=self.mensaje_id,
+                idCda=str(self.cda_id),
+                idMensaje=str(self.mensaje_id),
             )
         else:
             acuse = etree.Element(
                 'acuse',
-                idCda=self.cda_id,
+                idCda=str(self.cda_id),
             )
 
         etree.SubElement(
@@ -165,7 +159,7 @@ class Acuse(BaseModel):
             if tag == 'resultado_banxico':
                 cda_data[tag] = ResultadoBanxico(**banxico_data)
                 continue
-            if tag in cls.__fields__:
+            if tag in cls.model_fields:
                 cda_data[tag] = element.text
 
         return cls(**cda_data)
