@@ -1,10 +1,11 @@
 from typing import Optional
 
 from lxml import etree
-from pydantic import BaseModel
+from pydantic import BaseModel, ConfigDict
 
 from spei import types
-from spei.utils import to_snake_case, to_upper_camel_case  # noqa: WPS347
+from spei.types.common import DateInt, InstitutionCode
+from spei.utils import to_pascal_case, to_snake_case  # noqa: WPS347
 
 SOAP_NS = 'http://schemas.xmlsoap.org/soap/envelope/'
 PRAXIS_NS = 'http://www.praxis.com.mx/'
@@ -12,18 +13,20 @@ ENVIO_PRAXIS_NS = 'http://www.praxis.com.mx/EnvioCda/'
 
 
 class CDA(BaseModel):
+    model_config = ConfigDict(strict=False, coerce_numbers_to_str=True)
+
     id: int
     mensaje_id: int
-    op_fecha_oper: str
-    op_fecha_abono: str
-    op_hora_abono: str
+    op_fecha_oper: DateInt
+    op_fecha_abono: DateInt
+    op_hora_abono: int
 
     op_cve_rastreo: str
 
     op_folio_orig_odp: int
     op_folio_orig_paq: int
 
-    op_clave_emisor: str
+    op_clave_emisor: InstitutionCode
     op_nombre_emisor: str
 
     op_tipo_pag: types.TipoPagoOrdenPago
@@ -46,16 +49,27 @@ class CDA(BaseModel):
     op_rfc_curp_ben: Optional[str] = None
 
     op_iva: Optional[str] = None
-    op_hora_00: Optional[str] = None
+    op_hora_00: Optional[int] = None
 
     op_nom_part_indirecto_ord: Optional[str] = None
     op_cta_part_indirecto_ord: Optional[str] = None
     op_rfc_curp_part_indirecto_ord: Optional[str] = None
 
-    class Config:  # noqa: WPS306, WPS431
-        use_enum_values = True
+    # remesas
+    op_id_remesa: Optional[str] = None
+    op_pais: Optional[str] = None
+    op_divisa: Optional[str] = None
+    op_nom_emisor_rem: Optional[str] = None
+    op_cta_emisor_rem: Optional[str] = None
+    op_rfc_curp_emisor_rem: Optional[str] = None
+    op_nom_ben_rem: Optional[str] = None
+    op_cta_ben_rem: Optional[str] = None
+    op_rfc_curp_ben_rem: Optional[str] = None
+    op_nom_prov_rem_ext: Optional[str] = None
+    op_nom_prov_rem_nac: Optional[str] = None
+    model_config = ConfigDict(use_enum_values=True)
 
-    def build_xml(self):
+    def build_xml(self) -> etree._Element:  # noqa: WPS437
         mensaje = etree.Element(
             etree.QName(ENVIO_PRAXIS_NS, 'datosCda'),
             idCda=str(self.id),
@@ -66,8 +80,8 @@ class CDA(BaseModel):
         elements = self.dict(exclude_none=True, exclude={'id', 'mensaje_id'})
 
         for element, value in elements.items():  # noqa: WPS110
-            if element in self.__fields__:
-                upper_camel_case_element = to_upper_camel_case(element)
+            if element in self.model_fields:
+                upper_camel_case_element = to_pascal_case(element)
                 subelement = etree.SubElement(
                     mensaje,
                     etree.QName(ENVIO_PRAXIS_NS, upper_camel_case_element),
@@ -88,7 +102,7 @@ class CDA(BaseModel):
 
         for element in datos_cta.getchildren():
             tag = to_snake_case(element.tag)
-            if tag in cls.__fields__:
+            if tag in cls.model_fields:
                 cda_data[tag] = element.text
 
         return cls(**cda_data)
