@@ -1,10 +1,10 @@
 from typing import Optional, TypedDict
 
 from lxml import etree
-from pydantic import BaseModel
+from pydantic import BaseModel, ConfigDict, Field
 
 from spei import types
-from spei.utils import to_snake_case, to_upper_camel_case  # noqa: WPS347
+from spei.utils import to_pascal_case, to_snake_case  # noqa: WPS347
 
 
 class DataDict(TypedDict, total=False):
@@ -16,21 +16,21 @@ class DataDict(TypedDict, total=False):
 
 
 class Respuesta(BaseModel):
-    err_codigo: types.CodigoError
-    categoria: types.CategoriaOrdenPago
-    id: Optional[str]
-    fecha_oper: Optional[int]
-    err_descripcion: Optional[str]
+    model_config = ConfigDict(strict=False, coerce_numbers_to_str=True)
 
-    class Config:  # noqa: WPS306, WPS431
-        use_enum_values = True
+    categoria: types.CategoriaOrdenPago
+    err_codigo: Optional[types.CodigoError] = Field(default=None, validate_default=True)
+    id: Optional[int] = None
+    fecha_oper: Optional[int] = None
+    err_descripcion: Optional[str] = None
+    model_config = ConfigDict(use_enum_values=True)
 
     def build_xml(self):
         respuesta = etree.Element('respuesta')
 
         for element, value in self.dict(exclude={'categoria'}).items():  # noqa: WPS110
-            if element in self.__fields__:
-                upper_camel_case_element = to_upper_camel_case(element)
+            if element in self.model_fields:
+                upper_camel_case_element = to_pascal_case(element)
                 subelement = etree.SubElement(respuesta, upper_camel_case_element)
                 subelement.text = str(value)
 
@@ -46,4 +46,4 @@ class Respuesta(BaseModel):
             tag = to_snake_case(sub_element.tag)
             respuesta_data[tag] = sub_element.text  # type: ignore
 
-        return cls(**respuesta_data)
+        return cls.model_validate(respuesta_data)
